summaryrefslogtreecommitdiffstats
path: root/example
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:55:40 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:55:40 -0600
commit73ff676f11662d6178c8854a7832ebffe2ae409d (patch)
tree9e89ea7d87940087d2d3c5db9b378ef989dd1346 /example
parentc2ba2f56121c21a762619faf195e8332ef5b224f (diff)
downloadkoffice-73ff676f11662d6178c8854a7832ebffe2ae409d.tar.gz
koffice-73ff676f11662d6178c8854a7832ebffe2ae409d.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'example')
-rw-r--r--example/example_aboutdata.h8
-rw-r--r--example/example_factory.cc10
-rw-r--r--example/example_factory.h14
3 files changed, 16 insertions, 16 deletions
diff --git a/example/example_factory.cc b/example/example_factory.cc
index 261d75cd8..307b7e939 100644
--- a/example/example_factory.cc
+++ b/example/example_factory.cc
@@ -27,8 +27,8 @@
K_EXPORT_COMPONENT_FACTORY( libexamplepart, ExampleFactory )
-KInstance* ExampleFactory::s_global = 0L;
-KAboutData* ExampleFactory::s_aboutData = 0L;
+TDEInstance* ExampleFactory::s_global = 0L;
+TDEAboutData* ExampleFactory::s_aboutData = 0L;
ExampleFactory::ExampleFactory( TQObject* parent, const char* name )
: KoFactory( parent, name )
@@ -59,18 +59,18 @@ KParts::Part* ExampleFactory::createPartObject( TQWidget *parentWidget, const ch
return part;
}
-KAboutData* ExampleFactory::aboutData()
+TDEAboutData* ExampleFactory::aboutData()
{
if ( !s_aboutData )
s_aboutData = newExampleAboutData();
return s_aboutData;
}
-KInstance* ExampleFactory::global()
+TDEInstance* ExampleFactory::global()
{
if ( !s_global )
{
- s_global = new KInstance( aboutData() );
+ s_global = new TDEInstance( aboutData() );
// Add any application-specific resource directories here
// Tell the iconloader about share/apps/koffice/icons
diff --git a/example/example_aboutdata.h b/example/example_aboutdata.h
index a4ed180d0..895368761 100644
--- a/example/example_aboutdata.h
+++ b/example/example_aboutdata.h
@@ -26,14 +26,14 @@
static const char* description=I18N_NOOP("Example KOffice Program");
static const char* version="0.1";
-KAboutData * newExampleAboutData()
+TDEAboutData * newExampleAboutData()
{
// Change this, of course
// The first argument of the KAboutData constructor is the instance name.
// It is very important, it's what's used for many things, like the subdir in share/apps, etc.
// It must also match the name of the application's .desktop file.
- KAboutData * aboutData=new KAboutData( "example", I18N_NOOP("Example"),
- version, description, KAboutData::License_GPL,
+ TDEAboutData * aboutData=new TDEAboutData( "example", I18N_NOOP("Example"),
+ version, description, TDEAboutData::License_GPL,
"(c) 1998-2000, Torben Weis");
aboutData->addAuthor("Torben Weis",0, "weis@kde.org");
return aboutData;
@@ -26,14 +26,14 @@
{
// Change this, of course
- // The first argument of the KAboutData constructor is the instance name.
+ // The first argument of the TDEAboutData constructor is the instance name.
// It is very important, it's what's used for many things, like the subdir in share/apps, etc.
// It must also match the name of the application's .desktop file.
diff --git a/example/example_factory.h b/example/example_factory.h
index 6b6182161..791f40432 100644
--- a/example/example_factory.h
+++ b/example/example_factory.h
@@ -22,8 +22,8 @@
#include <KoFactory.h>
-class KInstance;
-class KAboutData;
+class TDEInstance;
+class TDEAboutData;
class ExampleFactory : public KoFactory
{
@@ -35,14 +35,14 @@ public:
virtual KParts::Part *createPartObject( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const TQStringList &args = TQStringList() );
- static KInstance* global();
+ static TDEInstance* global();
- // _Creates_ a KAboutData but doesn't keep ownership
- static KAboutData* aboutData();
+ // _Creates_ a TDEAboutData but doesn't keep ownership
+ static TDEAboutData* aboutData();
private:
- static KInstance* s_global;
- static KAboutData* s_aboutData;
+ static TDEInstance* s_global;
+ static TDEAboutData* s_aboutData;
};
#endif